OC.L10N.register(
    "accessibility",
    {
    "Dark theme" : "Тъмна тема",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Тъмна тема, която облекчава очите ви, като намалява яркостта. Все още е в процес на разработка, затова, моля, докладвайте за всички проблеми, които откриете.",
    "High contrast mode" : "Висок контраст",
    "Dyslexia font" : "Шрифт за дислексия",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic е безплатен шрифт, предназначен за смекчаване на някои от често срещаните грешки при четенето, причинени от дислексия.",
    "Accessibility" : "Достъпност",
    "Accessibility options for nextcloud" : "Опции за достъпност за nextcloud",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Осигурява множество опции за достъпност за улесняване на използването на Nextcloud",
    "Web Content Accessibility Guidelines" : "Указания за достъпност на уеб съдържание",
    "our design team" : "нашия екип",
    "Enable" : "Включване",
    "High contrast theme" : "Тема с висок контраст",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Тема с висок контраст за улесняване на навигацията. Визуалното качество ще бъде намалено, но яснотата ще бъде увеличена.",
    "Dark theme (beta)" : "Тъмна тема (бета)",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia. The typeface was created by Abelardo Gonzalez, who released it through an open-source license." : "OpenDyslexic е безплатен шрифт, предназначен за смекчаване на някои от често срещаните грешки при четенето, причинени от дислексия.",
    "Provides multiple accessibilities options to ease your use of nextcloud" : "Осигурява множество опции за достъпност за улесняване на използването на Nextcloud",
    "Themes" : "Теми",
    "Fonts" : "Шрифт",
    "enabled" : "Включено"
},
"nplurals=2; plural=(n != 1);");
